@@ -12,7 +12,7 @@ from requests.auth import HTTPBasicAuth
 import yaml
 import time
 
-VERSION = '0.5.0'
+VERSION = '0.5.2'
 
 backliftURL = {}
 default_backliftURL = 'https://www.backlift.com/'
@@ -84,7 +84,17 @@ def check_response(r):
         if r.status_code == 500:
             fail(ERR_500)
         elif r.status_code == 400:
-            fail(ERR_400 % r.content)
+            try:
+                err = json.loads(r.content)
+                errstrs = []
+                for key, val in err['form_errors'].items():
+                    if key:
+                        errstrs.append(key + ': ' + ', '.join(val))
+                    else:
+                        errstrs.append(', '.join(val))
+                fail(ERR_400 % '\n'.join(errstrs))
+            except (ValueError, KeyError):
+                fail(ERR_400 % r.content)
         elif r.status_code == 404:
             fail(ERR_404)
         elif r.status_code == 403:
@@ -217,13 +227,19 @@ def read_api_key():
     return api_key
 
 
-def setup_app(path, app_id, force=False):
-    filepath = os.path.join(path, backlift_cfg_folder, backlift_appid_file)
+def check_backlift_cfg(path, app_id, force=False):
+    filepath = os.path.join(path, backlift_cfg_folder)
 
     if os.path.exists(filepath) and not force:
         fail(ERR_INIT)
 
-    keyfile = open_create(filepath, 'w')
+    return filepath
+
+
+def setup_app(path, app_id, force=False):
+    filepath = check_backlift_cfg(path, app_id, force)
+
+    keyfile = open_create(os.path.join(filepath, backlift_appid_file), 'w')
     keyfile.write(app_id)
     keyfile.close()
 
@@ -258,15 +274,19 @@ def create_app(path, api_key, name, template, force=False):
                           auth=HTTPBasicAuth('api', api_key), 
                           verify=False, headers=headers)
         check_response(r)
+
         app_id = json.loads(r.text)['_id']
-        setup_app(path, app_id, force=force)
+        check_backlift_cfg(path, app_id, force=force)
 
         r = requests.post(backliftURL['create'], 
                           data={'appname': name, 'template': template},
                           auth=HTTPBasicAuth('api', api_key), 
                           verify=False, headers=headers)
         check_response(r)
-        return json.loads(r.text)['_id']
+
+        setup_app(path, app_id, force=force)
+
+        return app_id
 
     except requests.exceptions.ConnectionError:
         fail(ERR_SERVER)
@@ -496,9 +516,9 @@ def open_browser(path, admin=False):
     meta = get_app_meta(api_key, app_id)
 
     if admin:
-        url = meta.get('admin_url', '')
+        url = meta.get('_admin_url', '')
     else:
-        url = meta.get('app_url', '')
+        url = meta.get('_app_url', '')
 
     if not url:
         fail(ERR_NOURL)
@@ -582,7 +602,7 @@ def execute_command_line():
                 if len(tokens) > 1:
                     create(options.path, args[1], tokens[1], force=options.force)
                 else:
-                    create(options.path, args[1], 'basic', force=options.force)
+                    create(options.path, args[1], 'backbone-basic', force=options.force)
         elif args[0].lower().startswith('delete'):
             if len(args) < 2:
                 appname = '.'
